# Generated by Django 4.2.3 on 2023-07-24 09:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("email_notifications", "0005_add_field_reply_to_email"),
    ]

    operations = [
        migrations.AlterField(
            model_name="emailnotification",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
    ]
