{% load cms_tags %}
{% if user.is_authenticated and request.toolbar.edit_mode_active or display_content %}
    {% for plugin in instance.child_plugin_instances %}
        {% with forloop as parentloop %}{% render_plugin plugin %}{% endwith %}
    {% endfor %}
{% endif %}
